﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            TransformGroup transformGroup = new TransformGroup();

            transformGroup.Children.Add(new ScaleTransform());
            transformGroup.Children.Add(new RotateTransform());

            Rectangle rectangle = new Rectangle();

            rectangle.Name                  = "rectangle";
            rectangle.Width                 = 100;
            rectangle.Height                = 100;
            rectangle.RenderTransform       = transformGroup;
            rectangle.RenderTransformOrigin = new Point(0.5, 0.5);
            rectangle.Fill                  = Brushes.Blue;

            NameScope.SetNameScope(this, new NameScope());

            RegisterName(rectangle.Name, rectangle);

            DoubleAnimation doubleAnimation = new DoubleAnimation();

            doubleAnimation.Duration       = new Duration(TimeSpan.FromSeconds(5));
            doubleAnimation.RepeatBehavior = RepeatBehavior.Forever;
            doubleAnimation.From           = 0;
            doubleAnimation.To             = 360;

            PropertyPath propertyPath = new PropertyPath
            (
                "(0).(1)[1].(2)",
                new DependencyProperty[]
                {
                    Rectangle.RenderTransformProperty,
                    TransformGroup.ChildrenProperty,
                    RotateTransform.AngleProperty
                }
            );

            Storyboard.SetTargetName(doubleAnimation, rectangle.Name);
            Storyboard.SetTargetProperty(doubleAnimation, propertyPath);

            Storyboard storyboard = new Storyboard();

            storyboard.Children.Add(doubleAnimation);

            BeginStoryboard beginStoryboard = new BeginStoryboard();

            beginStoryboard.Storyboard = storyboard;

            EventTrigger enterTrigger = new EventTrigger();

            enterTrigger.RoutedEvent = Rectangle.LoadedEvent;

            enterTrigger.Actions.Add(beginStoryboard);

            rectangle.Triggers.Add(enterTrigger);

            Border border = new Border();

            border.Width      = 400;
            border.Height     = 400;
            border.Background = Brushes.LightGray;

            border.Child = rectangle;

            Content = border;
        }

        #endregion
    }
}